import {
  Controller,
  Get,
  Post,
  Query,
  Response,
  UploadedFile,
  UseInterceptors,
} from '@nestjs/common';
import { FileInterceptor } from '@nestjs/platform-express';
import { UploadFileService } from './upload-file.service';
import { IdInstitucionDto } from '../dto/id-institucion.dto';
import {ApiTags} from '@nestjs/swagger'

@Controller('upload-file')
@ApiTags('upload-file')
export class UploadFileController {
  constructor(private uploadFileService: UploadFileService) {}

  @Post('carga-masiva-equipos')
  @UseInterceptors(FileInterceptor('file'))
  cargaMasivaEquipos(
    @UploadedFile() file: Express.Multer.File,
    @Query() query: IdInstitucionDto,
  ) {
    this.uploadFileService.createEquipos(file, Number(query.id_institucion));
  }

  @Post('carga-masiva-usuarios')
  @UseInterceptors(FileInterceptor('file'))
  cargaMasivaUsuarios(
    @UploadedFile() file: Express.Multer.File,
    @Query() query: IdInstitucionDto,
  ) {
    this.uploadFileService.createEquipos(file, Number(query.id_institucion));
  }

  @Get('download-logo')
  downloadLogo(@Response() res, @Query() query: IdInstitucionDto) {
    return this.uploadFileService.downloadLogo(Number(query.id_institucion));
  }

  @Post('upload-logo')
  @UseInterceptors(FileInterceptor('file'))
  uploadLogo(
    @UploadedFile() file: Express.Multer.File,
    @Query() query: IdInstitucionDto,
  ) {
    this.uploadFileService.uploadLogo(file, Number(query.id_institucion));
  }
}
